@@ -1,9 +1,6 @@
 #include <rlang.h>
 #include "internal.h"
 
-// From call.c
-r_obj* rlang_call2(r_obj* fn, r_obj* args, r_obj* ns);
-
 
 r_obj* ffi_exec(r_obj* call, r_obj* op, r_obj* args, r_obj* rho) {
   args = r_node_cdr(args);
